package org.xbib.interlibrary.ldap.util;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import javax.naming.directory.Attribute;
import javax.naming.directory.BasicAttribute;
import javax.naming.directory.DirContext;
import javax.naming.directory.ModificationItem;

public class Modify {

    private final String dn;

    private final Map<String, Object> add;

    private final Map<String, Object> replace;

    private final Map<String, Object> remove;

    public Modify(String dn,
                  Map<String, Object> add,
                  Map<String, Object> replace,
                  Map<String, Object> remove) {
        this.dn = dn;
        this.add = add;
        this.replace = replace;
        this.remove = remove;
    }

    public String getName() {
        return dn;
    }

    public ModificationItem[] getModificationItems() {
        List<ModificationItem> list = new ArrayList<>();
        for (Map.Entry<String, Object> entry : add.entrySet()) {
            list.add(new ModificationItem(DirContext.ADD_ATTRIBUTE, create(entry)));
        }
        for (Map.Entry<String, Object> entry : replace.entrySet()) {
            list.add(new ModificationItem(DirContext.REPLACE_ATTRIBUTE, create(entry)));
        }
        for (Map.Entry<String, Object> entry : remove.entrySet()) {
            list.add(new ModificationItem(DirContext.REMOVE_ATTRIBUTE, create(entry)));
        }
        return list.toArray(new ModificationItem[0]);
    }

    private Attribute create(Map.Entry<String, Object> entry) {
        BasicAttribute attribute = new BasicAttribute(entry.getKey());
        Object object = entry.getValue();
        if (object instanceof Collection<?> collection) {
            for (Object o : collection) {
                attribute.add(o);
            }
        } else {
            attribute.add(object);
        }
        return attribute;
    }
}
