package org.xbib.interlibrary.ldap.util;

import javax.naming.directory.SearchControls;

public class Search {

    static final int DEFAULT_TIME_LIMIT = 5000;

    static final int DEFAULT_COUNT_LIMIT = 20000;

    private final SearchControls searchControls;

    private final String base;

    private final String filter;

    public Search(String base, SearchScope scope, String filter) {
        this(base, scope, filter, DEFAULT_TIME_LIMIT, DEFAULT_COUNT_LIMIT);
    }

    public Search(String base, SearchScope scope, String filter, int timeLimit, int countLimit) {
        this.base = base;
        this.filter = filter;
        this.searchControls = createSearchControls(scope, timeLimit, countLimit);
    }

    public String getBase() {
        return base;
    }

    public String getFilter() {
        return filter;
    }

    public SearchControls createSearchControls() {
        return searchControls;
    }

    private static SearchControls createSearchControls(SearchScope searchScope,
                                                       int timeLimit,
                                                       int countLimit) {
        SearchControls searchControls = new SearchControls();
        searchControls.setSearchScope(searchScope.getValue());
        searchControls.setReturningObjFlag(false);
        searchControls.setTimeLimit(timeLimit);
        searchControls.setCountLimit(countLimit);
        return searchControls;
    }
}
